@@ -491,26 +491,26 @@ class CalibrationClient(CalibrationApi,
 
         # Retrieve the desired retrieve Strategy
         # OPTIONS:
-        #   - closest_by_pdu (default)
-        #   - exactly_contained_by_pdu
-        #   - closest_by_detector
+        #   - pdu_closest_by_time (default)
+        #   - pdu_prior_in_time
+        #   - detector_closest_by_time
         if 'strategy' in retrieve_h:
             ret_strategy = retrieve_h['strategy']
         else:
-            ret_strategy = 'closest_by_pdu'
+            ret_strategy = 'pdu_closest_by_time'
 
         # Call proper method depending on the desired 'Strategy'
-        if ret_strategy == 'exactly_contained_by_pdu':
+        if ret_strategy == 'pdu_prior_in_time':
             resp = self.retrieve_calibration_constant_version_by_pdu(
                 ret_strategy, retrieve_h)
 
-        elif ret_strategy == 'closest_by_detector':
+        elif ret_strategy == 'detector_closest_by_time':
             resp = self.retrieve_calibration_constant_version_by_detector(
                 ret_strategy, retrieve_h)
 
         # if ret_strategy == '' or
         #    ret_strategy is None or
-        #    ret_strategy == 'closest_by_pdu':
+        #    ret_strategy == 'pdu_closest_by_time':
         else:
             resp = self.retrieve_calibration_constant_version_by_pdu(
                 ret_strategy, retrieve_h)
@@ -525,9 +525,9 @@ class CalibrationClient(CalibrationApi,
 
         # Retrieve the desired retrieve Strategy
         # OPTIONS:
-        #  - closest_by_pdu (default)
-        #  - exactly_contained_by_pdu
-        #  - closest_by_detector [ERROR! <= Not available in this method!]
+        #  - pdu_closest_by_time (default)
+        #  - pdu_prior_in_time
+        #  - detector_closest_by_time [ERROR! <= Not available in this method!]
 
         # Separate the inject_h into its main elements
         ret_detector_condition = retrieve_h['detector_condition']
@@ -603,7 +603,7 @@ class CalibrationClient(CalibrationApi,
         logging.debug('* calibration_constant_ids == {0}'.format(cc_ids))
 
         # Get calibration_constant_version
-        if ret_strategy == 'exactly_contained_by_pdu':
+        if ret_strategy == 'pdu_prior_in_time':
             resp = CalibrationConstantVersion.get_by_uk(self,
                                                         # Latest added CC!
                                                         cc_ids[0],
@@ -611,15 +611,15 @@ class CalibrationClient(CalibrationApi,
                                                         event_at,
                                                         snapshot_at)
 
-        elif ret_strategy == 'closest_by_detector':
-            error_msg = 'Strategy "closest_by_detector" not available in ' \
-                        'retrieve_calibration_constant_version'
+        elif ret_strategy == 'detector_closest_by_time':
+            error_msg = 'Strategy "detector_closest_by_time" not available ' \
+                        'in retrieve_calibration_constant_version'
             logging.error(error_msg)
             return resp
 
         # if ret_strategy == '' or
         #    ret_strategy is None or
-        #    ret_strategy == 'closest_by_pdu':
+        #    ret_strategy == 'pdu_closest_by_time':
         else:
             resp = CalibrationConstantVersion.get_closest_by_time(
                 self,
@@ -648,9 +648,9 @@ class CalibrationClient(CalibrationApi,
 
         # Retrieve the desired retrieve Strategy
         # OPTIONS:
-        #  - closest_by_pdu  [ERROR! <= Not available in this method!]
-        #  - exactly_contained_by_pdu [ERROR! <= Not available in this method!]
-        #  - closest_by_detector (default)
+        #  - pdu_closest_by_time  [ERROR! <= Not available in this method!]
+        #  - pdu_prior_in_time [ERROR! <= Not available in this method!]
+        #  - detector_closest_by_time (default)
 
         # Separate the inject_h into its main elements
         ret_detector_condition = retrieve_h['detector_condition']
@@ -744,21 +744,21 @@ class CalibrationClient(CalibrationApi,
         logging.debug('* phy_det_units == {0}'.format(all_phy_det_units))
 
         # Get calibration_constant_version
-        if ret_strategy == 'exactly_contained_by_pdu':
-            error_msg = 'Strategy "exactly_contained_by_pdu" not available' \
+        if ret_strategy == 'pdu_prior_in_time':
+            error_msg = 'Strategy "pdu_prior_in_time" not available' \
                         'in retrieve_calibration_constant_version_by_detector'
             logging.error(error_msg)
             return resp
 
-        elif ret_strategy == 'closest_by_pdu':
-            error_msg = 'Strategy "closest_by_pdu" not available in' \
+        elif ret_strategy == 'pdu_closest_by_time':
+            error_msg = 'Strategy "pdu_closest_by_time" not available in' \
                         ' retrieve_calibration_constant_version_by_detector'
             logging.error(error_msg)
             return resp
 
         # if ret_strategy == '' or
         #    ret_strategy is None or
-        #    ret_strategy == 'closest_by_detector':
+        #    ret_strategy == 'detector_closest_by_time':
         else:
             karabo_da = Util.get_opt_hash_val(retrieve_h, 'pdu_karabo_da')
             logging.debug('* karabo_da == {0}'.format(karabo_da))
