@@ -152,7 +152,7 @@ class CalibrationClientByDetectorTest(ModuleBase, unittest.TestCase):
             'calibration_name': cal_name,
 
             'pdu_physical_name': '',  # pdu_phy_name,
-            'strategy': 'closest_by_detector',
+            'strategy': 'detector_closest_by_time',
             'detector_identifier': detector_identifier,
             'pdu_karabo_da': pdu_karabo_da,
 
@@ -272,7 +272,7 @@ class CalibrationClientByDetectorTest(ModuleBase, unittest.TestCase):
             'calibration_name': cal_name,
 
             'pdu_physical_name': '',  # pdu_phy_name,
-            'strategy': 'closest_by_detector',
+            'strategy': 'detector_closest_by_time',
             'detector_identifier': detector_identifier,
             'pdu_karabo_da': '',  # Should return 1 version per each PDU
 
@@ -393,7 +393,7 @@ class CalibrationClientByDetectorTest(ModuleBase, unittest.TestCase):
             'calibration_name': cal_name,
 
             # 'pdu_physical_name': pdu_phy_name,
-            'strategy': 'closest_by_detector',
+            'strategy': 'detector_closest_by_time',
             'detector_identifier': detector_identifier,
             'pdu_karabo_da': pdu_karabo_da,
 
@@ -519,7 +519,7 @@ class CalibrationClientByDetectorTest(ModuleBase, unittest.TestCase):
             'calibration_name': cal_name,
 
             # 'pdu_physical_name': pdu_phy_name,
-            'strategy': 'closest_by_detector',
+            'strategy': 'detector_closest_by_time',
             'detector_identifier': detector_identifier,
             'pdu_karabo_da': pdu_karabo_da,
 
