@@ -18,14 +18,14 @@ class _CalibrationTestHash(object):
     def __init__(self, desired_begin_at=None):
         self.desired_begin_at = desired_begin_at
 
-        self.valid_inject_01 = _CalibrationTestHash._build_valid_test_hash_01(
-            desired_begin_at)
-        self.valid_inject_by_det_01 = _CalibrationTestHash._build_valid_test_hash_03(
-            desired_begin_at)
-        self.valid_search_01 = _CalibrationTestHash._build_valid_test_hash_02(
-            desired_begin_at)
-        self.valid_search_by_det_01 = _CalibrationTestHash._build_valid_test_hash_04(
-            desired_begin_at)
+        self.valid_inject_01 = \
+            _CalibrationTestHash._build_valid_test_hash_01(desired_begin_at)
+        self.valid_inject_by_det_01 = \
+            _CalibrationTestHash._build_valid_test_hash_03(desired_begin_at)
+        self.valid_search_01 = \
+            _CalibrationTestHash._build_valid_test_hash_02(desired_begin_at)
+        self.valid_search_by_det_01 = \
+            _CalibrationTestHash._build_valid_test_hash_04(desired_begin_at)
 
     @staticmethod
     def _build_valid_test_hash_01(desired_begin_at):
@@ -273,10 +273,13 @@ class _CalibrationTestHash(object):
         ccv_h = {
             'name': ccv_name,  # If present, must be unique
 
-            # If pdu_physical_name is present, detector_identifier and pdu_karabo_da are ignored
+            # If pdu_physical_name is present,
+            # detector_identifier and pdu_karabo_da are ignored
             'pdu_physical_name': pdu_phy_name,
             'detector_identifier': detector_identifier,
             'pdu_karabo_da': pdu_karabo_da,
+            # end comment
+
             'path_to_file': path_to_file,
             'file_name': 'test_01',
             'flg_good_quality': 1,
